yakumo.nova.v2.interface_attachment

Package yakumo :: Package nova :: Package v2 :: Module interface_attachment |
[hide private]
[frames] | no frames]

# Module interface_attachment

source code

Resource class and its manager for interface attachment in Compute API v2

Classes | [hide private]
| Resource Resource class for interface attachment in Compute API v2
| Manager Manager class for interface attachment in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``port``'``,` `'``port_id``'``,` <yakumo.mapper.Resour`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('port', 'port_id', mapper.Resource('port')), ('id', 'port_id', mappe
      r.Resource('port')), ('network', 'net_id', mapper.Resource('network'))
      , ('mac_addr', 'mac_addr', mapper.Noop), ('fixed_ips', 'fixed_ips', ma
      pper.Noop), ('status', 'port_state', mapper.Noop),]